==> curl_8.15.0~rc2.orig.tar.xz: curl-8.15.0-rc2/tests/unit/units.c <==
/* !checksrc! disable COPYRIGHT all */

#include "first.h"

#include "unit1300.c"
#include "unit1302.c"
#include "unit1303.c"
#include "unit1304.c"
#include "unit1305.c"
#include "unit1307.c"
#include "unit1309.c"
#include "unit1323.c"
#include "unit1330.c"
#include "unit1395.c"
#include "unit1396.c"
#include "unit1397.c"
#include "unit1398.c"
#include "unit1399.c"
#include "unit1600.c"
#include "unit1601.c"
#include "unit1602.c"
#include "unit1603.c"
#include "unit1605.c"
#include "unit1606.c"
#include "unit1607.c"
#include "unit1608.c"
#include "unit1609.c"
#include "unit1610.c"
#include "unit1611.c"
#include "unit1612.c"
#include "unit1614.c"
#include "unit1615.c"
#include "unit1616.c"
#include "unit1620.c"
#include "unit1650.c"
#include "unit1651.c"
#include "unit1652.c"
#include "unit1653.c"
#include "unit1654.c"
#include "unit1655.c"
#include "unit1656.c"
#include "unit1657.c"
#include "unit1658.c"
#include "unit1660.c"
#include "unit1661.c"
#include "unit1663.c"
#include "unit1664.c"
#include "unit1979.c"
#include "unit1980.c"
#include "unit2600.c"
#include "unit2601.c"
#include "unit2602.c"
#include "unit2603.c"
#include "unit2604.c"
#include "unit3200.c"
#include "unit3205.c"
#include "unit3211.c"
#include "unit3212.c"
#include "unit3213.c"

const struct entry_s s_entries[] = {
  {"unit1300", test_unit1300},
  {"unit1302", test_unit1302},
  {"unit1303", test_unit1303},
  {"unit1304", test_unit1304},
  {"unit1305", test_unit1305},
  {"unit1307", test_unit1307},
  {"unit1309", test_unit1309},
  {"unit1323", test_unit1323},
  {"unit1330", test_unit1330},
  {"unit1395", test_unit1395},
  {"unit1396", test_unit1396},
  {"unit1397", test_unit1397},
  {"unit1398", test_unit1398},
  {"unit1399", test_unit1399},
  {"unit1600", test_unit1600},
  {"unit1601", test_unit1601},
  {"unit1602", test_unit1602},
  {"unit1603", test_unit1603},
  {"unit1605", test_unit1605},
  {"unit1606", test_unit1606},
  {"unit1607", test_unit1607},
  {"unit1608", test_unit1608},
  {"unit1609", test_unit1609},
  {"unit1610", test_unit1610},
  {"unit1611", test_unit1611},
  {"unit1612", test_unit1612},
  {"unit1614", test_unit1614},
  {"unit1615", test_unit1615},
  {"unit1616", test_unit1616},
  {"unit1620", test_unit1620},
  {"unit1650", test_unit1650},
  {"unit1651", test_unit1651},
  {"unit1652", test_unit1652},
  {"unit1653", test_unit1653},
  {"unit1654", test_unit1654},
  {"unit1655", test_unit1655},
  {"unit1656", test_unit1656},
  {"unit1657", test_unit1657},
  {"unit1658", test_unit1658},
  {"unit1660", test_unit1660},
  {"unit1661", test_unit1661},
  {"unit1663", test_unit1663},
  {"unit1664", test_unit1664},
  {"unit1979", test_unit1979},
  {"unit1980", test_unit1980},
  {"unit2600", test_unit2600},
  {"unit2601", test_unit2601},
  {"unit2602", test_unit2602},
  {"unit2603", test_unit2603},
  {"unit2604", test_unit2604},
  {"unit3200", test_unit3200},
  {"unit3205", test_unit3205},
  {"unit3211", test_unit3211},
  {"unit3212", test_unit3212},
  {"unit3213", test_unit3213},
  {NULL, NULL}
};

#include "first.c"

==> curl_8.18.0~rc2.orig.tar.xz: curl-8.18.0-rc2/tests/unit/units.c <==
/* !checksrc! disable COPYRIGHT all */

#include "first.h"

#include "unit1300.c"
#include "unit1302.c"
#include "unit1303.c"
#include "unit1304.c"
#include "unit1305.c"
#include "unit1307.c"
#include "unit1309.c"
#include "unit1323.c"
#include "unit1330.c"
#include "unit1395.c"
#include "unit1396.c"
#include "unit1397.c"
#include "unit1398.c"
#include "unit1399.c"
#include "unit1600.c"
#include "unit1601.c"
#include "unit1602.c"
#include "unit1603.c"
#include "unit1605.c"
#include "unit1606.c"
#include "unit1607.c"
#include "unit1608.c"
#include "unit1609.c"
#include "unit1610.c"
#include "unit1611.c"
#include "unit1612.c"
#include "unit1614.c"
#include "unit1615.c"
#include "unit1616.c"
#include "unit1620.c"
#include "unit1650.c"
#include "unit1651.c"
#include "unit1652.c"
#include "unit1653.c"
#include "unit1654.c"
#include "unit1655.c"
#include "unit1656.c"
#include "unit1657.c"
#include "unit1658.c"
#include "unit1660.c"
#include "unit1661.c"
#include "unit1663.c"
#include "unit1664.c"
#include "unit1979.c"
#include "unit1980.c"
#include "unit2600.c"
#include "unit2601.c"
#include "unit2602.c"
#include "unit2603.c"
#include "unit2604.c"
#include "unit2605.c"
#include "unit3200.c"
#include "unit3205.c"
#include "unit3211.c"
#include "unit3212.c"
#include "unit3213.c"
#include "unit3214.c"
#include "unit3216.c"

const struct entry_s s_entries[] = {
  {"unit1300", test_unit1300},
  {"unit1302", test_unit1302},
  {"unit1303", test_unit1303},
  {"unit1304", test_unit1304},
  {"unit1305", test_unit1305},
  {"unit1307", test_unit1307},
  {"unit1309", test_unit1309},
  {"unit1323", test_unit1323},
  {"unit1330", test_unit1330},
  {"unit1395", test_unit1395},
  {"unit1396", test_unit1396},
  {"unit1397", test_unit1397},
  {"unit1398", test_unit1398},
  {"unit1399", test_unit1399},
  {"unit1600", test_unit1600},
  {"unit1601", test_unit1601},
  {"unit1602", test_unit1602},
  {"unit1603", test_unit1603},
  {"unit1605", test_unit1605},
  {"unit1606", test_unit1606},
  {"unit1607", test_unit1607},
  {"unit1608", test_unit1608},
  {"unit1609", test_unit1609},
  {"unit1610", test_unit1610},
  {"unit1611", test_unit1611},
  {"unit1612", test_unit1612},
  {"unit1614", test_unit1614},
  {"unit1615", test_unit1615},
  {"unit1616", test_unit1616},
  {"unit1620", test_unit1620},
  {"unit1650", test_unit1650},
  {"unit1651", test_unit1651},
  {"unit1652", test_unit1652},
  {"unit1653", test_unit1653},
  {"unit1654", test_unit1654},
  {"unit1655", test_unit1655},
  {"unit1656", test_unit1656},
  {"unit1657", test_unit1657},
  {"unit1658", test_unit1658},
  {"unit1660", test_unit1660},
  {"unit1661", test_unit1661},
  {"unit1663", test_unit1663},
  {"unit1664", test_unit1664},
  {"unit1979", test_unit1979},
  {"unit1980", test_unit1980},
  {"unit2600", test_unit2600},
  {"unit2601", test_unit2601},
  {"unit2602", test_unit2602},
  {"unit2603", test_unit2603},
  {"unit2604", test_unit2604},
  {"unit2605", test_unit2605},
  {"unit3200", test_unit3200},
  {"unit3205", test_unit3205},
  {"unit3211", test_unit3211},
  {"unit3212", test_unit3212},
  {"unit3213", test_unit3213},
  {"unit3214", test_unit3214},
  {"unit3216", test_unit3216},
  {NULL, NULL}
};

#include "first.c"
